@@ -1,15 +1,13 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
-from functools import reduce
 import json
 import logging
+from functools import reduce
 
-from django.contrib.admin.views import main
 from django.contrib.admin.actions import delete_selected
+from django.contrib.admin.views import main
 from django.contrib.auth import get_permission_codename
 from django.db.models import Q
 from django.http import (
@@ -19,23 +17,17 @@ from django.http import (
     HttpResponseNotFound,
     HttpResponseServerError,
 )
+from django.templatetags.static import static
+from django.utils.encoding import force_str
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
-from django.utils.translation import gettext_lazy as _, gettext
-from django.utils.encoding import force_text
-
+from django.utils.translation import gettext, gettext_lazy as _
 from mptt.exceptions import InvalidMove
 from mptt.forms import MPTTAdminForm
 
 from feincms import settings
 from feincms.extensions import ExtensionModelAdmin
 
-try:
-    # Django<3
-    from django.contrib.staticfiles.templatetags.staticfiles import static
-except ImportError:
-    from django.templatetags.static import static
-
 
 logger = logging.getLogger(__name__)
 
@@ -54,7 +46,7 @@ def django_boolean_icon(field_val, alt_text=None, title=None):
     else:
         title = ""
     icon_url = static("feincms/img/icon-%s.gif" % BOOLEAN_MAPPING[field_val])
-    return mark_safe('<img src="%s" alt="%s" %s/>' % (icon_url, alt_text, title))
+    return mark_safe(f'<img src="{icon_url}" alt="{alt_text}" {title}/>')
 
 
 def _build_tree_structure(queryset):
@@ -144,12 +136,12 @@ class ChangeList(main.ChangeList):
 
     def __init__(self, request, *args, **kwargs):
         self.user = request.user
-        super(ChangeList, self).__init__(request, *args, **kwargs)
+        super().__init__(request, *args, **kwargs)
 
     def get_queryset(self, *args, **kwargs):
         mptt_opts = self.model._mptt_meta
         qs = (
-            super(ChangeList, self)
+            super()
             .get_queryset(*args, **kwargs)
             .order_by(mptt_opts.tree_id_attr, mptt_opts.left_attr)
         )
@@ -185,7 +177,7 @@ class ChangeList(main.ChangeList):
                     reduce(lambda p, q: p | q, clauses)
                 )
 
-        super(ChangeList, self).get_results(request)
+        super().get_results(request)
 
         # Pre-process permissions because we still have the request here,
         # which is not passed in later stages in the tree editor
@@ -218,7 +210,7 @@ class TreeEditor(ExtensionModelAdmin):
         list_per_page = 999999999
 
     def __init__(self, *args, **kwargs):
-        super(TreeEditor, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.list_display = list(self.list_display)
 
@@ -391,7 +383,7 @@ class TreeEditor(ExtensionModelAdmin):
 
         except Exception:
             logger.exception("Unhandled exception while toggling %s on %s", attr, obj)
-            return HttpResponseServerError("Unable to toggle %s on %s" % (attr, obj))
+            return HttpResponseServerError(f"Unable to toggle {attr} on {obj}")
 
         # Weed out unchanged cells to keep the updates small. This assumes
         # that the order a possible get_descendents() returns does not change
@@ -414,7 +406,7 @@ class TreeEditor(ExtensionModelAdmin):
             self.list_display.append("actions_column")
 
         # handle common AJAX requests
-        if request.is_ajax():
+        if "__cmd" in request.POST:
             cmd = request.POST.get("__cmd")
             if cmd == "toggle_boolean":
                 return self._toggle_boolean(request)
@@ -437,9 +429,7 @@ class TreeEditor(ExtensionModelAdmin):
             )
         )
 
-        return super(TreeEditor, self).changelist_view(
-            request, extra_context, *args, **kwargs
-        )
+        return super().changelist_view(request, extra_context, *args, **kwargs)
 
     def has_add_permission(self, request, obj=None):
         """
@@ -452,7 +442,7 @@ class TreeEditor(ExtensionModelAdmin):
         else:
             r = request.user.has_perm(perm)
 
-        return r and super(TreeEditor, self).has_add_permission(request)
+        return r and super().has_add_permission(request)
 
     def has_change_permission(self, request, obj=None):
         """
@@ -465,7 +455,7 @@ class TreeEditor(ExtensionModelAdmin):
         else:
             r = request.user.has_perm(perm)
 
-        return r and super(TreeEditor, self).has_change_permission(request, obj)
+        return r and super().has_change_permission(request, obj)
 
     def has_delete_permission(self, request, obj=None):
         """
@@ -478,7 +468,7 @@ class TreeEditor(ExtensionModelAdmin):
         else:
             r = request.user.has_perm(perm)
 
-        return r and super(TreeEditor, self).has_delete_permission(request, obj)
+        return r and super().has_delete_permission(request, obj)
 
     def _move_node(self, request):
         if hasattr(self.model.objects, "move_node"):
@@ -543,7 +533,7 @@ class TreeEditor(ExtensionModelAdmin):
                     if self.has_delete_permission(request, obj):
                         obj.delete()
                         n += 1
-                        obj_display = force_text(obj)
+                        obj_display = force_str(obj)
                         self.log_deletion(request, obj, obj_display)
                     else:
                         logger.warning(
@@ -563,7 +553,7 @@ class TreeEditor(ExtensionModelAdmin):
             return delete_selected(self, request, queryset)
 
     def get_actions(self, request):
-        actions = super(TreeEditor, self).get_actions(request)
+        actions = super().get_actions(request)
         if "delete_selected" in actions:
             actions["delete_selected"] = (
                 self.delete_selected_tree,
