@@ -1,40 +1,27 @@
-from __future__ import absolute_import
-
+import warnings
 from collections import OrderedDict
 from email.utils import parsedate
 from functools import partial, wraps
 from time import mktime
-import warnings
 
 from django.conf import settings
 from django.core.cache import cache
 from django.db import models
 from django.http import HttpResponse
 from django.template.response import TemplateResponse
+from django.urls import (
+    NoReverseMatch,
+    Resolver404,
+    get_script_prefix,
+    resolve,
+    reverse,
+    set_script_prefix,
+)
 from django.utils.functional import lazy
 from django.utils.http import http_date
 from django.utils.safestring import mark_safe
 from django.utils.translation import get_language, gettext_lazy as _
 
-try:
-    from django.urls import (
-        NoReverseMatch,
-        reverse,
-        get_script_prefix,
-        set_script_prefix,
-        Resolver404,
-        resolve,
-    )
-except ImportError:
-    from django.core.urlresolvers import (
-        NoReverseMatch,
-        reverse,
-        get_script_prefix,
-        set_script_prefix,
-        Resolver404,
-        resolve,
-    )
-
 from feincms.admin.item_editor import ItemEditorForm
 from feincms.contrib.fields import JSONField
 from feincms.translations import short_language_code
@@ -239,7 +226,7 @@ class ApplicationContent(models.Model):
             custom_fields = {}
 
             def __init__(self, *args, **kwargs):
-                super(ApplicationContentItemEditorForm, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
 
                 instance = kwargs.get("instance", None)
 
@@ -276,15 +263,13 @@ class ApplicationContent(models.Model):
                 # get the model so we can set .parameters to the values of our
                 # custom fields before calling save(commit=True)
 
-                m = super(ApplicationContentItemEditorForm, self).save(
-                    commit=False, *args, **kwargs
-                )
+                m = super().save(commit=False, *args, **kwargs)
 
-                m.parameters = dict(
-                    (k, self.cleaned_data[k])
+                m.parameters = {
+                    k: self.cleaned_data[k]
                     for k in self.custom_fields
                     if k in self.cleaned_data
-                )
+                }
 
                 if commit:
                     m.save(**kwargs)
@@ -296,7 +281,7 @@ class ApplicationContent(models.Model):
         cls.feincms_item_editor_form = ApplicationContentItemEditorForm
 
     def __init__(self, *args, **kwargs):
-        super(ApplicationContent, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.app_config = self.ALL_APPS_CONFIG.get(self.urlconf_path, {}).get(
             "config", {}
         )
@@ -321,7 +306,7 @@ class ApplicationContent(models.Model):
             fn, args, kwargs = resolve(path, urlconf_path)
         except (ValueError, Resolver404):
             raise Resolver404(
-                str("Not found (resolving %r in %r failed)") % (path, urlconf_path)
+                f"Not found (resolving {path!r} in {urlconf_path!r} failed)"
             )
 
         # Variables from the ApplicationContent parameters are added to request
@@ -385,9 +370,14 @@ class ApplicationContent(models.Model):
             mimetype = mimetype.split(";")[0]
         mimetype = mimetype.strip()
 
+        is_ajax = (
+            request.is_ajax()
+            if hasattr(request, "is_ajax")
+            else request.headers.get("x-requested-with") == "XMLHttpRequest"
+        )
         return (
             response.status_code != 200
-            or request.is_ajax()
+            or is_ajax
             or getattr(response, "standalone", False)
             or mimetype not in ("text/html", "text/plain")
         )
@@ -412,9 +402,9 @@ class ApplicationContent(models.Model):
         # Ideally, for the Cache-Control header, we'd want to do some
         # intelligent combining, but that's hard. Let's just collect and unique
         # them and let the client worry about that.
-        cc_headers = set(("must-revalidate",))
+        cc_headers = {"must-revalidate"}
         for x in (cc.split(",") for cc in headers.get("Cache-Control", ())):
-            cc_headers |= set((s.strip() for s in x))
+            cc_headers |= {s.strip() for s in x}
 
         if len(cc_headers):
             response["Cache-Control"] = ", ".join(cc_headers)
@@ -433,7 +423,7 @@ class ApplicationContent(models.Model):
 
     @classmethod
     def app_reverse_cache_key(self, urlconf_path, **kwargs):
-        return "FEINCMS:%s:APPCONTENT:%s:%s" % (
+        return "FEINCMS:{}:APPCONTENT:{}:{}".format(
             getattr(settings, "SITE_ID", 0),
             get_language(),
             urlconf_path,
