@@ -5,7 +5,6 @@ You can provide your own comment form by passing an additional
 ``form=YourClass`` argument to the ``create_content_type`` call.
 """
 
-from __future__ import absolute_import, unicode_literals
 
 from django import forms
 from django.core.mail import send_mail
@@ -14,8 +13,6 @@ from django.http import HttpResponseRedirect
 from django.template.loader import render_to_string
 from django.utils.translation import gettext_lazy as _
 
-from feincms._internal import ct_render_to_string
-
 
 class ContactForm(forms.Form):
     name = forms.CharField(label=_("name"))
@@ -43,7 +40,7 @@ class ContactFormContent(models.Model):
 
     def process(self, request, **kwargs):
         if request.GET.get("_cf_thanks"):
-            self.rendered_output = ct_render_to_string(
+            self.rendered_output = render_to_string(
                 "content/contactform/thanks.html", {"content": self}, request=request
             )
             return
@@ -71,7 +68,7 @@ class ContactFormContent(models.Model):
 
             form = self.form(initial=initial)
 
-        self.rendered_output = ct_render_to_string(
+        self.rendered_output = render_to_string(
             "content/contactform/form.html",
             {"content": self, "form": form},
             request=request,
