@@ -3,7 +3,6 @@ Simple file inclusion content: You should probably use the media library
 instead.
 """
 
-from __future__ import absolute_import, unicode_literals
 
 import os
 
@@ -11,7 +10,6 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from feincms import settings
-from feincms._internal import ct_render_to_string
 
 
 class FileContent(models.Model):
@@ -31,9 +29,7 @@ class FileContent(models.Model):
         verbose_name_plural = _("files")
 
     def render(self, **kwargs):
-        return ct_render_to_string(
+        return (
             ["content/file/%s.html" % self.region, "content/file/default.html"],
             {"content": self},
-            request=kwargs.get("request"),
-            context=kwargs.get("context"),
         )
