@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 from django.conf import settings as django_settings
 from django.contrib import admin
 from django.core.exceptions import ImproperlyConfigured
@@ -7,7 +5,6 @@ from django.db import models
 from django.utils.translation import gettext_lazy as _
 
 from feincms import settings
-from feincms._internal import ct_render_to_string
 from feincms.admin.item_editor import FeinCMSInline
 from feincms.contrib.richtext import RichTextField
 from feincms.module.medialibrary.fields import MediaFileForeignKey
@@ -83,16 +80,14 @@ class SectionContent(models.Model):
         else:
             mediafile_type = "nomedia"
 
-        return ct_render_to_string(
+        return (
             [
-                "content/section/%s_%s.html" % (mediafile_type, self.type),
+                f"content/section/{mediafile_type}_{self.type}.html",
                 "content/section/%s.html" % mediafile_type,
                 "content/section/%s.html" % self.type,
                 "content/section/default.html",
             ],
             {"content": self},
-            request=kwargs.get("request"),
-            context=kwargs.get("context"),
         )
 
     def save(self, *args, **kwargs):
@@ -106,6 +101,6 @@ class SectionContent(models.Model):
                 # content instance along
                 self.richtext = self.cleanse.im_func(self.richtext)
 
-        super(SectionContent, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     save.alters_data = True
