@@ -1,9 +1,6 @@
-from __future__ import absolute_import, unicode_literals
-
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
-from feincms._internal import ct_render_to_string
 from feincms.content.raw.models import RawContent  # noqa
 from feincms.content.richtext.models import RichTextContent  # noqa
 
@@ -33,9 +30,7 @@ class TemplateContent(models.Model):
         )
 
     def render(self, **kwargs):
-        return ct_render_to_string(
+        return (
             self.template,
             {"content": self},
-            request=kwargs.get("request"),
-            context=kwargs.get("context"),
         )
