@@ -1,12 +1,8 @@
-from __future__ import absolute_import, unicode_literals
-
 import re
 
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
-from feincms._internal import ct_render_to_string
-
 
 class VideoContent(models.Model):
     """
@@ -73,9 +69,7 @@ class VideoContent(models.Model):
 
     def render(self, **kwargs):
         ctx = self.ctx_for_video(self.video)
-        return ct_render_to_string(
+        return (
             self.get_templates(ctx["portal"]),
             ctx,
-            request=kwargs.get("request"),
-            context=kwargs.get("context"),
         )
