@@ -1,14 +1,9 @@
-from __future__ import absolute_import, unicode_literals
-
 import json
 import logging
-import six
-from distutils.version import LooseVersion
 
-from django import get_version
 from django import forms
-from django.db import models
 from django.core.serializers.json import DjangoJSONEncoder
+from django.db import models
 
 
 class JSONFormField(forms.fields.CharField):
@@ -16,7 +11,7 @@ class JSONFormField(forms.fields.CharField):
         # It seems that sometimes we receive dict objects here, not only
         # strings. Partial form validation maybe?
         if value:
-            if isinstance(value, six.string_types):
+            if isinstance(value, str):
                 try:
                     value = json.loads(value)
                 except ValueError:
@@ -29,16 +24,10 @@ class JSONFormField(forms.fields.CharField):
             except ValueError:
                 raise forms.ValidationError("Invalid JSON data!")
 
-        return super(JSONFormField, self).clean(value, *args, **kwargs)
+        return super().clean(value, *args, **kwargs)
 
 
-if LooseVersion(get_version()) > LooseVersion("1.8"):
-    workaround_class = models.TextField
-else:
-    workaround_class = six.with_metaclass(models.SubfieldBase, models.TextField)
-
-
-class JSONField(workaround_class):
+class JSONField(models.TextField):
     """
     TextField which transparently serializes/unserializes JSON objects
 
@@ -53,7 +42,7 @@ class JSONField(workaround_class):
 
         if isinstance(value, dict):
             return value
-        elif isinstance(value, six.string_types) or isinstance(value, six.binary_type):
+        elif isinstance(value, str) or isinstance(value, bytes):
             # Avoid asking the JSON decoder to handle empty values:
             if not value:
                 return {}
@@ -96,6 +85,6 @@ class JSONField(workaround_class):
         if isinstance(value, dict):
             value = json.dumps(value, cls=DjangoJSONEncoder)
 
-        assert isinstance(value, six.string_types)
+        assert isinstance(value, str)
 
         return value
