@@ -1,5 +1,4 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 """
 Default settings for FeinCMS
@@ -8,10 +7,10 @@ All of these can be overridden by specifying them in the standard
 ``settings.py`` file.
 """
 
-from __future__ import absolute_import, unicode_literals
 
 from django.conf import settings
 
+
 # e.g. 'uploads' if you would prefer <media root>/uploads/imagecontent/test.jpg
 # to <media root>/imagecontent/test.jpg.
 FEINCMS_UPLOAD_PREFIX = getattr(settings, "FEINCMS_UPLOAD_PREFIX", "")
