@@ -1,9 +1,7 @@
-from __future__ import absolute_import, unicode_literals
-
 import os
 
 from django.core.management.base import NoArgsCommand
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 
 from feincms.module.medialibrary.models import MediaFile
 
@@ -18,5 +16,5 @@ class Command(NoArgsCommand):
         for base, dirs, files in os.walk("media/medialibrary"):
             for f in files:
                 full = os.path.join(base[6:], f)
-                if force_text(full) not in mediafiles:
+                if force_str(full) not in mediafiles:
                     self.stdout.write(os.path.join(base, f))
