@@ -5,30 +5,27 @@ All models defined here are abstract, which means no tables are created in
 the feincms namespace.
 """
 
-from __future__ import absolute_import, unicode_literals
 
+import operator
+import sys
+import warnings
 from collections import OrderedDict
 from functools import reduce
-import six
-import sys
-import operator
-import warnings
 
+import six
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ImproperlyConfigured
 from django.db import connections, models
 from django.db.models import Q
 from django.forms.widgets import Media
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.utils.translation import gettext_lazy as _
 
-from feincms import ensure_completely_loaded
 from feincms.extensions import ExtensionsMixin
 from feincms.utils import copy_model_instance
 
 
-@six.python_2_unicode_compatible
-class Region(object):
+class Region:
     """
     This class represents a region inside a template. Example regions might be
     'main' and 'sidebar'.
@@ -41,7 +38,7 @@ class Region(object):
         self._content_types = []
 
     def __str__(self):
-        return force_text(self.title)
+        return force_str(self.title)
 
     @property
     def content_types(self):
@@ -55,8 +52,7 @@ class Region(object):
         ]
 
 
-@six.python_2_unicode_compatible
-class Template(object):
+class Template:
     """
     A template is a standard Django template which is used to render a
     CMS object, most commonly a page.
@@ -83,13 +79,13 @@ class Template(object):
             return Region(*data)
 
         self.regions = [_make_region(row) for row in regions]
-        self.regions_dict = dict((r.key, r) for r in self.regions)
+        self.regions_dict = {r.key: r for r in self.regions}
 
     def __str__(self):
-        return force_text(self.title)
+        return force_str(self.title)
 
 
-class ContentProxy(object):
+class ContentProxy:
     """
     The ``ContentProxy`` is responsible for loading the content blocks for all
     regions (including content blocks in inherited regions) and assembling
@@ -240,10 +236,10 @@ class ContentProxy(object):
                 for instance in content_list:
                     contents.setdefault(instance.region, []).append(instance)
 
-            self._cache["regions"] = dict(
-                (region, sorted(instances, key=lambda c: c.ordering))
+            self._cache["regions"] = {
+                region: sorted(instances, key=lambda c: c.ordering)
                 for region, instances in contents.items()
-            )
+            }
 
         return self._cache["regions"]
 
@@ -414,8 +410,6 @@ def create_base_model(inherit_from=models.Model):
                 )
 
                 def _template(self):
-                    ensure_completely_loaded()
-
                     try:
                         return self._feincms_templates[self.template_key]
                     except KeyError:
@@ -666,7 +660,7 @@ def create_base_model(inherit_from=models.Model):
             feincms_content_base = cls._feincms_content_model
 
             class Meta(feincms_content_base.Meta):
-                db_table = "%s_%s" % (cls._meta.db_table, class_name.lower())
+                db_table = f"{cls._meta.db_table}_{class_name.lower()}"
                 verbose_name = model._meta.verbose_name
                 verbose_name_plural = model._meta.verbose_name_plural
                 permissions = model._meta.permissions
@@ -693,7 +687,7 @@ def create_base_model(inherit_from=models.Model):
 
             # content types can be limited to a subset of regions
             if not regions:
-                regions = set([region.key for region in cls._feincms_all_regions])
+                regions = {region.key for region in cls._feincms_all_regions}
 
             for region in cls._feincms_all_regions:
                 if region.key in regions:
@@ -738,7 +732,6 @@ def create_base_model(inherit_from=models.Model):
                         incls
                     )
 
-            ensure_completely_loaded(force=True)
             return new_type
 
         @property
@@ -771,8 +764,6 @@ def create_base_model(inherit_from=models.Model):
 
         @classmethod
         def _needs_templates(cls):
-            ensure_completely_loaded()
-
             # helper which can be used to ensure that either register_regions
             # or register_templates has been executed before proceeding
             if not hasattr(cls, "template"):
@@ -783,8 +774,6 @@ def create_base_model(inherit_from=models.Model):
 
         @classmethod
         def _needs_content_types(cls):
-            ensure_completely_loaded()
-
             # Check whether any content types have been created for this base
             # class
             if not getattr(cls, "_feincms_content_types", None):
@@ -826,7 +815,7 @@ def create_base_model(inherit_from=models.Model):
                 try:
                     from reversion import register
                 except ImportError:
-                    raise EnvironmentError("django-reversion is not installed")
+                    raise OSError("django-reversion is not installed")
 
             follow = []
             for content_type in cls._feincms_content_types:
