@@ -1,11 +1,10 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import
 
 import logging
 
+
 # ------------------------------------------------------------------------
 logger = logging.getLogger("feincms.medialibrary")
 
