@@ -1,36 +1,29 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
 import os
 
 from django import forms
 from django.conf import settings as django_settings
-from django.contrib import admin
-from django.contrib import messages
+from django.contrib import admin, messages
 from django.contrib.auth.decorators import permission_required
 from django.contrib.sites.shortcuts import get_current_site
 from django.core.files.images import get_image_dimensions
 from django.http import HttpResponseRedirect
 from django.shortcuts import render
 from django.template.defaultfilters import filesizeformat
+from django.urls import reverse
 from django.utils.safestring import mark_safe
-from django.utils.translation import ungettext, gettext_lazy as _
+from django.utils.translation import gettext_lazy as _, ngettext
 from django.views.decorators.csrf import csrf_protect
 
-try:
-    from django.urls import reverse
-except ImportError:
-    from django.core.urlresolvers import reverse
-
 from feincms.extensions import ExtensionModelAdmin
 from feincms.translations import admin_translationinline, lookup_translations
 from feincms.utils import shorten_string
 
-from .models import Category, MediaFileTranslation
 from .forms import MediaCategoryAdminForm, MediaFileAdminForm
+from .models import Category, MediaFileTranslation
 from .thumbnail import admin_thumbnail
 from .zip import import_zipfile
 
@@ -63,7 +56,7 @@ def assign_category(modeladmin, request, queryset):
                 count += 1
 
             message = (
-                ungettext(
+                ngettext(
                     "Successfully added %(count)d media file to %(category)s.",
                     "Successfully added %(count)d media files to %(category)s.",
                     count,
@@ -126,24 +119,22 @@ class MediaFileAdmin(ExtensionModelAdmin):
     actions = [assign_category, save_as_zipfile]
 
     def get_urls(self):
-        from django.conf.urls import url
+        from django.urls import re_path
 
         return [
-            url(
+            re_path(
                 r"^mediafile-bulk-upload/$",
                 self.admin_site.admin_view(MediaFileAdmin.bulk_upload),
                 {},
                 name="mediafile_bulk_upload",
             )
-        ] + super(MediaFileAdmin, self).get_urls()
+        ] + super().get_urls()
 
     def changelist_view(self, request, extra_context=None):
         if extra_context is None:
             extra_context = {}
         extra_context["categories"] = Category.objects.order_by("title")
-        return super(MediaFileAdmin, self).changelist_view(
-            request, extra_context=extra_context
-        )
+        return super().changelist_view(request, extra_context=extra_context)
 
     def admin_thumbnail(self, obj):
         image = admin_thumbnail(obj)
@@ -184,7 +175,7 @@ class MediaFileAdmin(ExtensionModelAdmin):
                 d = get_image_dimensions(obj.file.file)
                 if d:
                     t += " %d&times;%d" % (d[0], d[1])
-            except (IOError, TypeError, ValueError) as e:
+            except (OSError, TypeError, ValueError) as e:
                 t += " (%s)" % e
         return mark_safe(t)
 
@@ -238,15 +229,11 @@ class MediaFileAdmin(ExtensionModelAdmin):
         return HttpResponseRedirect(reverse("admin:medialibrary_mediafile_changelist"))
 
     def get_queryset(self, request):
-        return (
-            super(MediaFileAdmin, self)
-            .get_queryset(request)
-            .transform(lookup_translations())
-        )
+        return super().get_queryset(request).transform(lookup_translations())
 
     def save_model(self, request, obj, form, change):
         obj.purge_translation_cache()
-        return super(MediaFileAdmin, self).save_model(request, obj, form, change)
+        return super().save_model(request, obj, form, change)
 
 
 # ------------------------------------------------------------------------
