@@ -1,14 +1,10 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
 import os
 import re
-import six
 
-import django
 from django.db import models
 from django.db.models.signals import post_delete
 from django.dispatch.dispatcher import receiver
@@ -19,9 +15,9 @@ from django.utils.translation import gettext_lazy as _
 from feincms import settings
 from feincms.models import ExtensionsMixin
 from feincms.translations import (
+    TranslatedObjectManager,
     TranslatedObjectMixin,
     Translation,
-    TranslatedObjectManager,
 )
 
 from . import logger
@@ -35,11 +31,10 @@ class CategoryManager(models.Manager):
     """
 
     def get_queryset(self):
-        return super(CategoryManager, self).get_queryset().select_related("parent")
+        return super().get_queryset().select_related("parent")
 
 
 # ------------------------------------------------------------------------
-@six.python_2_unicode_compatible
 class Category(models.Model):
     """
     These categories are meant primarily for organizing media files in the
@@ -69,7 +64,7 @@ class Category(models.Model):
 
     def __str__(self):
         if self.parent_id:
-            return "%s - %s" % (self.parent.title, self.title)
+            return f"{self.parent.title} - {self.title}"
 
         return self.title
 
@@ -77,7 +72,7 @@ class Category(models.Model):
         if not self.slug:
             self.slug = slugify(self.title)
 
-        super(Category, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     save.alters_data = True
 
@@ -89,11 +84,10 @@ class Category(models.Model):
         return p
 
     def path(self):
-        return " - ".join((f.title for f in self.path_list()))
+        return " - ".join(f.title for f in self.path_list())
 
 
 # ------------------------------------------------------------------------
-@six.python_2_unicode_compatible
 class MediaFileBase(models.Model, ExtensionsMixin, TranslatedObjectMixin):
     """
     Abstract media file class. Includes the
@@ -144,13 +138,10 @@ class MediaFileBase(models.Model, ExtensionsMixin, TranslatedObjectMixin):
         cls.filetypes[0:0] = types
         choices = [t[0:2] for t in cls.filetypes]
         cls.filetypes_dict = dict(choices)
-        if django.VERSION < (1, 9):
-            cls._meta.get_field("type").choices[:] = choices
-        else:
-            cls._meta.get_field("type").choices = choices
+        cls._meta.get_field("type").choices = choices
 
     def __init__(self, *args, **kwargs):
-        super(MediaFileBase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if self.file:
             self._original_file_name = self.file.name
 
@@ -177,16 +168,15 @@ class MediaFileBase(models.Model, ExtensionsMixin, TranslatedObjectMixin):
 
     def determine_file_type(self, name):
         """
-        >>> t = MediaFileBase()
-        >>> str(t.determine_file_type('foobar.jpg'))
+        >>> str(MediaFile().determine_file_type('foobar.jpg'))
         'image'
-        >>> str(t.determine_file_type('foobar.PDF'))
+        >>> str(MediaFile().determine_file_type('foobar.PDF'))
         'pdf'
-        >>> str(t.determine_file_type('foobar.jpg.pdf'))
+        >>> str(MediaFile().determine_file_type('foobar.jpg.pdf'))
         'pdf'
-        >>> str(t.determine_file_type('foobar.jgp'))
+        >>> str(MediaFile().determine_file_type('foobar.jgp'))
         'other'
-        >>> str(t.determine_file_type('foobar-jpg'))
+        >>> str(MediaFile().determine_file_type('foobar-jpg'))
         'other'
         """
         for type_key, type_name, type_test in self.filetypes:
@@ -202,10 +192,10 @@ class MediaFileBase(models.Model, ExtensionsMixin, TranslatedObjectMixin):
         if self.file:
             try:
                 self.file_size = self.file.size
-            except (OSError, IOError, ValueError) as e:
-                logger.error("Unable to read file size for %s: %s" % (self, e))
+            except (OSError, ValueError) as e:
+                logger.error(f"Unable to read file size for {self}: {e}")
 
-        super(MediaFileBase, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
         logger.info(
             "Saved mediafile %d (%s, type %s, %d bytes)"
@@ -228,7 +218,7 @@ class MediaFileBase(models.Model, ExtensionsMixin, TranslatedObjectMixin):
         try:
             self.file.storage.delete(name)
         except Exception as e:
-            logger.warn("Cannot delete media file %s: %s" % (name, e))
+            logger.warn(f"Cannot delete media file {name}: {e}")
 
 
 # ------------------------------------------------------------------------
@@ -292,7 +282,6 @@ def _mediafile_post_delete(sender, instance, **kwargs):
 
 
 # ------------------------------------------------------------------------
-@six.python_2_unicode_compatible
 class MediaFileTranslation(Translation(MediaFile)):
     """
     Translated media file caption and description.
