@@ -1,8 +1,6 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
 import re
 
@@ -11,9 +9,6 @@ from django.contrib.admin.widgets import ForeignKeyRawIdWidget
 from django.forms.models import model_to_dict
 from django.utils.safestring import mark_safe
 from django.utils.translation import gettext_lazy as _
-
-from feincms import ensure_completely_loaded
-
 from mptt.forms import MPTTAdminForm
 
 
@@ -30,7 +25,7 @@ class RedirectToWidget(ForeignKeyRawIdWidget):
             model = apps.get_model(matches["app_label"], matches["model_name"])
             try:
                 instance = model._default_manager.get(pk=int(matches["pk"]))
-                return "&nbsp;<strong>%s (%s)</strong>" % (
+                return "&nbsp;<strong>{} ({})</strong>".format(
                     instance,
                     instance.get_absolute_url(),
                 )
@@ -63,8 +58,6 @@ class PageAdminForm(MPTTAdminForm):
         return self.page_model._default_manager
 
     def __init__(self, *args, **kwargs):
-        ensure_completely_loaded()
-
         if "initial" in kwargs:
             if "parent" in kwargs["initial"]:
                 # Prefill a few form values from the parent page
@@ -118,7 +111,7 @@ class PageAdminForm(MPTTAdminForm):
 
         # Not required, only a nice-to-have for the `redirect_to` field
         modeladmin = kwargs.pop("modeladmin", None)
-        super(PageAdminForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if modeladmin and "redirect_to" in self.fields:
             # Note: Using `parent` is not strictly correct, but we can be
             # sure that `parent` always points to another page instance,
@@ -158,7 +151,7 @@ class PageAdminForm(MPTTAdminForm):
             self.fields["template_key"].choices = choices
 
     def clean(self):
-        cleaned_data = super(PageAdminForm, self).clean()
+        cleaned_data = super().clean()
 
         # No need to think further, let the user correct errors first
         if self._errors:
@@ -181,7 +174,7 @@ class PageAdminForm(MPTTAdminForm):
         redirect_to = cleaned_data.get("redirect_to")
         if redirect_to and re.match(r"^\d+$", redirect_to):
             opts = self.page_model._meta
-            cleaned_data["redirect_to"] = "%s.%s:%s" % (
+            cleaned_data["redirect_to"] = "{}.{}:{}".format(
                 opts.app_label,
                 opts.model_name,
                 redirect_to,
@@ -212,7 +205,7 @@ class PageAdminForm(MPTTAdminForm):
             parent = cleaned_data["parent"]
 
         if parent:
-            new_url = "%s%s/" % (parent._cached_url, cleaned_data["slug"])
+            new_url = "{}{}/".format(parent._cached_url, cleaned_data["slug"])
         else:
             new_url = "/%s/" % cleaned_data["slug"]
 
