@@ -1,32 +1,19 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
 from functools import partial
 from threading import local
 
 from django.conf import settings as django_settings
-from django.core.exceptions import PermissionDenied
+from django.contrib import admin, messages
 from django.contrib.contenttypes.models import ContentType
-from django.contrib import admin
-from django.contrib import messages
+from django.core.exceptions import PermissionDenied
 from django.http import HttpResponseRedirect
+from django.templatetags.static import static
+from django.urls import reverse
 from django.utils.translation import gettext_lazy as _
 
-try:
-    from django.urls import reverse
-except ImportError:
-    from django.core.urlresolvers import reverse
-
-try:
-    from django.contrib.staticfiles.templatetags.staticfiles import static
-except ImportError:
-    # Newer Django versions.
-    from django.templatetags.static import static
-
-from feincms import ensure_completely_loaded
 from feincms import settings
 from feincms.admin import item_editor, tree_editor
 
@@ -83,36 +70,34 @@ class PageAdmin(item_editor.ItemEditor, tree_editor.TreeEditor):
             cls.fieldsets[1][1]["fields"].extend(f)
 
     def __init__(self, model, admin_site):
-        ensure_completely_loaded()
-
         if len(model._feincms_templates) > 4 and "template_key" in self.radio_fields:
             del self.radio_fields["template_key"]
 
-        super(PageAdmin, self).__init__(model, admin_site)
+        super().__init__(model, admin_site)
 
     in_navigation_toggle = tree_editor.ajax_editable_boolean(
         "in_navigation", _("in navigation")
     )
 
     def get_readonly_fields(self, request, obj=None):
-        readonly = super(PageAdmin, self).get_readonly_fields(request, obj=obj)
+        readonly = super().get_readonly_fields(request, obj=obj)
         if not settings.FEINCMS_SINGLETON_TEMPLATE_CHANGE_ALLOWED:
             if obj and obj.template and obj.template.singleton:
                 return tuple(readonly) + ("template_key",)
         return readonly
 
     def get_form(self, *args, **kwargs):
-        form = super(PageAdmin, self).get_form(*args, **kwargs)
+        form = super().get_form(*args, **kwargs)
         return partial(form, modeladmin=self)
 
     def _actions_column(self, page):
         addable = getattr(page, "feincms_addable", True)
 
-        preview_url = "../../r/%s/%s/" % (
+        preview_url = "../../r/{}/{}/".format(
             ContentType.objects.get_for_model(self.model).id,
             page.id,
         )
-        actions = super(PageAdmin, self)._actions_column(page)
+        actions = super()._actions_column(page)
 
         if addable:
             if not page.template.enforce_leaf:
@@ -161,10 +146,10 @@ class PageAdmin(item_editor.ItemEditor, tree_editor.TreeEditor):
                     "language_name": language,
                     "translation_of": original,
                 }
-        return super(PageAdmin, self).add_view(request, **kwargs)
+        return super().add_view(request, **kwargs)
 
     def response_add(self, request, obj, *args, **kwargs):
-        response = super(PageAdmin, self).response_add(request, obj, *args, **kwargs)
+        response = super().response_add(request, obj, *args, **kwargs)
         if (
             "parent" in request.GET
             and "_addanother" in request.POST
@@ -206,7 +191,7 @@ class PageAdmin(item_editor.ItemEditor, tree_editor.TreeEditor):
 
     def change_view(self, request, object_id, **kwargs):
         try:
-            return super(PageAdmin, self).change_view(request, object_id, **kwargs)
+            return super().change_view(request, object_id, **kwargs)
         except PermissionDenied:
             messages.add_message(
                 request,
@@ -219,13 +204,13 @@ class PageAdmin(item_editor.ItemEditor, tree_editor.TreeEditor):
         if not settings.FEINCMS_SINGLETON_TEMPLATE_DELETION_ALLOWED:
             if obj and obj.template.singleton:
                 return False
-        return super(PageAdmin, self).has_delete_permission(request, obj=obj)
+        return super().has_delete_permission(request, obj=obj)
 
     def changelist_view(self, request, *args, **kwargs):
         _local.visible_pages = list(
             self.model.objects.active().values_list("id", flat=True)
         )
-        return super(PageAdmin, self).changelist_view(request, *args, **kwargs)
+        return super().changelist_view(request, *args, **kwargs)
 
     def is_visible_admin(self, page):
         """
