@@ -1,5 +1,4 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 #
 #  Created by Martin J. Laubach on 2011-08-01
@@ -7,14 +6,14 @@
 #
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
 from django.dispatch import Signal
 
+
 # ------------------------------------------------------------------------
 # This signal is sent when an item editor managed object is completely
 # saved, especially including all foreign or manytomany dependencies.
 
-itemeditor_post_save_related = Signal(providing_args=["instance", "created"])
+itemeditor_post_save_related = Signal()
 
 # ------------------------------------------------------------------------
