@@ -1,15 +1,9 @@
-from __future__ import absolute_import, unicode_literals
-
 from django import template
 from django.template import TemplateSyntaxError
 from django.template.defaulttags import kwarg_re
+from django.urls import NoReverseMatch
 from django.utils.encoding import smart_str
 
-try:
-    from django.urls import NoReverseMatch
-except ImportError:
-    from django.core.urlresolvers import NoReverseMatch
-
 from feincms.content.application.models import (
     ApplicationContent,
     app_reverse as do_app_reverse,
@@ -68,12 +62,9 @@ class AppReverseNode(template.Node):
 
     def render(self, context):
         args = [arg.resolve(context) for arg in self.args]
-        kwargs = dict(
-            [
-                (smart_str(k, "ascii"), v.resolve(context))
-                for k, v in self.kwargs.items()
-            ]
-        )
+        kwargs = {
+            smart_str(k, "ascii"): v.resolve(context) for k, v in self.kwargs.items()
+        }
         view_name = self.view_name.resolve(context)
         urlconf = self.urlconf.resolve(context)
 
