@@ -1,12 +1,9 @@
 # ------------------------------------------------------------------------
-# coding=utf-8
 # ------------------------------------------------------------------------
 
-from __future__ import absolute_import, unicode_literals
 
 import logging
 
-import django
 from django import template
 from django.conf import settings
 from django.utils.safestring import mark_safe
@@ -15,9 +12,6 @@ from feincms.utils import get_singleton, get_singleton_url
 
 
 register = template.Library()
-assignment_tag = (
-    register.simple_tag if django.VERSION >= (1, 9) else register.assignment_tag
-)
 
 
 def _render_content(content, **kwargs):
@@ -29,7 +23,7 @@ def _render_content(content, **kwargs):
         level = getattr(request, "feincms_render_level", 0)
         if level > 10:
             logging.getLogger("feincms").error(
-                "Refusing to render %r, render level is already %s" % (content, level)
+                f"Refusing to render {content!r}, render level is already {level}"
             )
             return
         setattr(request, "feincms_render_level", level + 1)
@@ -45,9 +39,6 @@ def _render_content(content, **kwargs):
             try:
                 engine = context.template.engine
             except AttributeError:
-                # This fails hard in Django 1.7 (ImportError). So what. This
-                # just means that this particular feature isn't available
-                # there.
                 from django.template.engine import Engine
 
                 engine = Engine.get_default()
@@ -94,7 +85,7 @@ def feincms_render_content(context, content, request=None):
     return _render_content(content, request=request, context=context)
 
 
-@assignment_tag
+@register.simple_tag
 def feincms_load_singleton(template_key, cls=None):
     """
     {% feincms_load_singleton template_key %} -- return a FeinCMS
