@@ -81,20 +81,18 @@ ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
 
-from __future__ import absolute_import, unicode_literals
 
-import django
 from django.db import models
 
 
 class TransformQuerySet(models.query.QuerySet):
     def __init__(self, *args, **kwargs):
-        super(TransformQuerySet, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._transform_fns = []
         self._orig_iterable_class = getattr(self, "_iterable_class", None)
 
     def _clone(self, *args, **kwargs):
-        c = super(TransformQuerySet, self)._clone(*args, **kwargs)
+        c = super()._clone(*args, **kwargs)
         c._transform_fns = self._transform_fns[:]
         return c
 
@@ -103,34 +101,11 @@ class TransformQuerySet(models.query.QuerySet):
         c._transform_fns.extend(fn)
         return c
 
-    if django.VERSION < (1, 11):
-
-        def iterator(self):
-            result_iter = super(TransformQuerySet, self).iterator()
-
-            if not self._transform_fns:
-                return result_iter
-
-            if (
-                getattr(self, "_iterable_class", None) != self._orig_iterable_class
-            ):  # noqa
-                # Do not process the result of values() and values_list()
-                return result_iter
-
-            results = list(result_iter)
+    def _fetch_all(self):
+        super()._fetch_all()
+        if getattr(self, "_iterable_class", None) == self._orig_iterable_class:  # noqa
             for fn in self._transform_fns:
-                fn(results)
-            return iter(results)
-
-    else:
-
-        def _fetch_all(self):
-            super(TransformQuerySet, self)._fetch_all()
-            if (
-                getattr(self, "_iterable_class", None) == self._orig_iterable_class
-            ):  # noqa
-                for fn in self._transform_fns:
-                    fn(self._result_cache)
+                fn(self._result_cache)
 
 
 if hasattr(models.Manager, "from_queryset"):
